## This program is free software; you can redistribute it and/or modify it under
## the terms of the GNU General Public License as published by the Free Software
## Foundation; either version 3 of the License, or (at your option) any later
## version.
##
## This program is distributed in the hope that it will be useful, but WITHOUT
## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
## FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
## details.
##
## You should have received a copy of the GNU General Public License along with
## this program; if not, see <http://www.gnu.org/licenses/>.
##
## Tzvetomir Tzvetanov, 2023/03/09
##
function efsz = EffectsizePrintOut(a,d,varargin);
  % for 2way within-subject ANOVA
  % a - ANOVA structure from nANOVA_WS()
  % d - the data input to nANOVA_WS()
  % Tzvetomir Tzvetanov, 2023/03/09

  printout = false;
  if nargin>2 printout=varargin{1}; endif

  % subjects SS, dfs
  dim = size(d); dfS=dim(3)-1;
  SSs = dim(1)*dim(2)*sum( (mean(mean(d,1),2)(:)-mean(d(:))).^2 );

  FA = a.AtoZ(1,4);
  dfA = a.AtoZ(1,2);
  eta = a.AtoZ(1,end);
  dfAerr = a.AStoZS(1,2);
  SSA = a.AtoZ(1,1);
  SSAerr = a.AStoZS(1,1);

  FB = a.AtoZ(2,4);
  dfB = a.AtoZ(2,2);
  etb = a.AtoZ(2,end);
  dfBerr = a.AStoZS(2,2);
  SSB = a.AtoZ(2,1);
  SSBerr = a.AStoZS(2,1);

  FAB = a.AB(1,4);
  dfAB = a.AB(1,2);
  etab = a.AB(1,end);
  dfABerr = a.ABS(1,2);
  SSAB = a.AB(1,1);
  SSABerr = a.ABS(1,1);

  % non centrality parameter
  ncpa = eta*dfA*FA; % non centrality parameter
  ncpb = etb*dfB*FB; % non centrality parameter
  ncpab = etab*dfAB*FAB; % non centrality parameter

  % post-hoc power of the results
  powa = ncfcdf_ab( finv(1-0.05,eta*dfA,eta*dfAerr),eta*dfA,eta*dfAerr,ncpa,'upper' );
  powb = ncfcdf_ab( finv(1-0.05,etb*dfB,etb*dfBerr),etb*dfB,etb*dfBerr,ncpb,'upper' );
  powab = ncfcdf_ab( finv(1-0.05,etab*dfAB,etab*dfABerr),etab*dfAB,etab*dfABerr,ncpab,'upper' );

  om2a = max(0,(SSA-SSAerr*dfA/dfAerr) / (SSA+SSAerr+SSs*(1+1/dfS)));
  om2b = max(0,(SSB-SSBerr*dfB/dfBerr) / (SSB+SSBerr+SSs*(1+1/dfS)));
  om2ab = max(0,(SSAB-SSABerr*dfAB/dfABerr) / (SSAB+SSABerr+SSs*(1+1/dfS)));

  % normalised max diff between means
  d = d - repmat(mean(mean(d,1),2),[dim(1:2),1]); % adjust for subjects
  ma = mean( mean( d, 2 ), 3 ); sa = mean( std( mean( d, 2 ), [], 3 ) ); da = (max(ma)-min(ma))/sa;
  mb = mean( mean( d, 1 ), 3 ); sb = mean( std( mean( d, 1 ), [], 3 ) ); db = (max(mb)-min(mb))/sb;
  mu=mean(d(:)); ab = d-repmat(ma,[1,dim(2),dim(3)])-repmat(mb,[dim(1),1,dim(3)])+mu;
  mab = mean( ab, 3 )(:); sab = mean( std( ab, [], 3 )(:) ); dab = (max(mab)-min(mab))/sab;

  if printout
    fprintf('______________________________________________________\n')
    fprintf('Effect  Obs.Power  ncp   partial-eta2  omega2   dnorm\n')
    fprintf('  A       %6.3f %6.2f    %.3f        %.3f   %.3f\n', powa, ncpa, SSA/(SSA+SSAerr), om2a, da);
    fprintf('  B       %6.3f %6.2f    %.3f        %.3f   %.3f\n', powb, ncpb, SSB/(SSB+SSBerr), om2b, db);
    fprintf(' AB       %6.3f %6.2f    %.3f        %.3f   %.3f\n', powab, ncpab, SSAB/(SSAB+SSABerr), om2ab, dab);
    fprintf('______________________________________________________\n');
  endif

  efsz(1,:) = [powa, ncpa, SSA/(SSA+SSAerr), om2a, da];
  efsz(2,:) = [powb, ncpb, SSB/(SSB+SSBerr), om2b, db];
  efsz(3,:) = [powab, ncpab, SSAB/(SSAB+SSABerr), om2ab, dab];

endfunction
