## This program is free software; you can redistribute it and/or modify it under
## the terms of the GNU General Public License as published by the Free Software
## Foundation; either version 3 of the License, or (at your option) any later
## version.
##
## This program is distributed in the hope that it will be useful, but WITHOUT
## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
## FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
## details.
##
## You should have received a copy of the GNU General Public License along with
## this program; if not, see <http://www.gnu.org/licenses/>.

function res = populationprevalence_cw(k,n,varargin)
  %
  % gnu octave script for basic population prevalence computation
  % based on the paper and some of the scripts of:
  %  Bayesian inference of population prevalence
  %  RAA Ince, AT Paton, JW Kay & PG Schyns
  %  (2021) eLife 10:e62461 doi: 10.7554/eLife.62461
  %
  % this script assumes flat prior r=s=1, and beta=1
  %
  % tzvetomir tzvetanov 2023/03/10

  pkg load statistics;

  be=1;
  if nargin<3 al=0.05; else al=varargin{1}; endif
  if nargin<4 phpdi=0.96; else phpdi=varargin{2}; endif

  g=(k/n-al)/(be-al); %map
  if g<0 g=0; endif

  st=0.00001; % this defines the precision of the hpdi estimate
  b=0:st:1;
  post = (be-al)*betapdf(al+(be-al)*b,k+1,n-k+1)./...
    (betacdf(be,k+1,n-k+1)-betacdf(al,k+1,n-k+1)); % equ from Ince et al's code
  % extract hpdi
  stpp=0.001; pp=stpp; sp=1;
  while sp>phpdi sp=sum(post(post>pp).*st); pp+=stpp; endwhile
  pp-=stpp; % take out one too much
  blim=b(find(post>=pp)([1,end]));
  fprintf('  at alpha=%.3f, MAP: %.3f, HPDI(%2d)=[%.4f,%.4f]\n',al,g,100*phpdi,blim);

  % output assignment
  res.k_n = [k,n];
  res.alpha = al;
  res.beta = be;
  res.map = g;
  res.hpdiprob = phpdi;
  res.hpdi = blim;

endfunction
