## This program is free software; you can redistribute it and/or modify it under
## the terms of the GNU General Public License as published by the Free Software
## Foundation; either version 3 of the License, or (at your option) any later
## version.
##
## This program is distributed in the hope that it will be useful, but WITHOUT
## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
## FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
## details.
##
## You should have received a copy of the GNU General Public License along with
## this program; if not, see <http://www.gnu.org/licenses/>.
##
## Tzvetomir Tzvetanov, 2023/03/09
##

%
% this script runs a simulation for testing the interaction effect, including
% power analysis and effect sizes, looking at what amount of change of the
% measured curve could be "detected" when applying the original hypothesis
%

clear all;

pkg load io statistics;

load localglobal_hjf_exp5_data_analysis.mat;

% EXP5
exp5.aov = rmfield(exp5.aov, {'bias','threshold'});

%sw = -1:0.01:1;
sw = 0:0.01:1; % it turns out this is enough; sw<0 i shighly significant ...
env = exp5.Envelope_or;
fl = exp5.Flank_or;

if 1
  % bias simulations
  fprintf( '\n  BIAS simulation:' );
  for ii=1:numel(sw)
    if rem(ii,5)==0 fprintf(' %d',ii); endif
    b = exp5.Biases;
    benv = mean(mean(b,2),3);
    bfl = mean(mean(b,1),3);
    bm = mean(b(:)); % global mean
    b = b - bm;
    b = b - repmat( benv, [1,12,7] ); % take out env effects
    b = b - repmat( bfl, [8,1,7] ); % take out fl effects
    for ie=1:8 % create the simulated effect across envelope positions
      x = abs(env(ie)/90);
      b(ie,:,:) = b(ie,:,:) + benv(ie) + reshape( repmat( ( x + sw(ii)*( 1 - x ) )*bfl', [1,7] ), [1,12,7]) - bm ;
    endfor
    bb = nANOVA_WS(b,'no');
    efsz = EffectsizePrintOut( bb, b );
    inter.p(ii) = bb.AB(7); % HF p value
    inter.efsz(ii,:) = efsz(3,:); % interaction effect sizes
  endfor
  iinter = find(inter.p<0.05)(end);
  fprintf( '\n  BIAS  simulation of interaction start significant at:' );
  fprintf( '\n  Switch = amplitude factor applied to the 90deg env. condition fpr obtaining the 0deg condition' );
  fprintf( '\n  Switch = 0 is a "flat" curve as a function of flank or. at 0deg envelope' );
  fprintf( '\n  Switch = -1 is (-1) times the 90deg curve as a function of flank or. at 0deg envelope' );
  fprintf( '\n   Switch     p   power  ncp  partial-eta2 om2  dnorm' );
  fprintf( '\n   %.3f   %.3f  %.3f  %.1f  %8.3f   %.3f  %.2f\n\n',  [sw(iinter),inter.p(iinter),inter.efsz(iinter,:)]);
endif

if 0
  sw = -1:0.01:1;
  % threshold simulations -> BUT this is meaningless... 
  % why should thresholds "flip" around their mean ? i.e. original hypothesis not stated
  fprintf( '\n  THRESHOLD simulation:' );
  for ii=1%:numel(sw) % use only the -1 case, already not working
    if rem(ii,5)==0 fprintf(' %d',ii); endif
    b = log10(exp5.Thresholds);
    bm = mean(b(:)); % global mean
    b = b - bm;
    benv = mean(mean(b,2),3);
    bfl = mean(mean(b,1),3);
    b = b - repmat( benv, [1,12,7] ); % take out env effects
    b = b - repmat( bfl, [8,1,7] ); % take out fl effects
    for ie=1:8
      x = abs(env(ie)/90);
      %b(ie,:,:) = bm + b(ie,:,:) + benv(ie) + reshape( repmat( ( x + sw(ii)*( 1 - x ) )*bfl', [1,7] ), [1,12,7]) ;
      b(ie,:,:) = bm + b(ie,:,:) + benv(ie) + reshape( repmat( ( x + sw(ii)*( 1 - x ) )*bfl', [1,7] ), [1,12,7]) ;
    endfor
    bb = nANOVA_WS(b,'yes');
    efsz = EffectsizePrintOut( bb, b );
    tinter.p(ii) = bb.AB(7); % HF p value
    tinter.efsz(ii,:) = efsz(3,:); % interaction effect sizes
  endfor
  iinter = find(tinter.p<0.05)(end);
  fprintf( '\n\n\n  THRESHOLDS   simulation of interaction start significant at:' );
  fprintf( '\n  Switch = amplitude factor applied to the 90deg env. condition fpr obtaining the 0deg condition' );
  fprintf( '\n  Switch = 0 is a "flat" curve as a function of flank or. at 0deg envelope' );
  fprintf( '\n  Switch = -1 is (-1) times the 90deg curve as a function of flank or. at 0deg envelope' );
  fprintf( '\n   Switch     p   power  ncp  partial-eta2 om2  dnorm' );
  fprintf( '\n   %.3f   %.3f  %.3f  %.1f  %8.3f   %.3f  %.2f\n\n',  [sw(iinter),tinter.p(iinter),tinter.efsz(iinter,:)]);
endif


