## This program is free software; you can redistribute it and/or modify it under
## the terms of the GNU General Public License as published by the Free Software
## Foundation; either version 3 of the License, or (at your option) any later
## version.
##
## This program is distributed in the hope that it will be useful, but WITHOUT
## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
## FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
## details.
##
## You should have received a copy of the GNU General Public License along with
## this program; if not, see <http://www.gnu.org/licenses/>.
##
## Tzvetomir Tzvetanov, 2023/03/09
##

% make plots of EXP5 data for manuscript
% adding panel 6 for elongated gaussian envelope (EXP1)
% adding figure for thresholds
% adding figure for response times

clear all;
pkg load io statistics;

load localglobal_hjf_exp5_data_analysis_onlyRTs.mat;
exp5RTs = exp5;
load localglobal_hjf_exp5_data_analysis.mat;
load localglobal_hjf_exp1_OneLapseInBlock_data_analysis.mat;
bdak = xlsread('dakin-fig6b.xlsx');
tdak = xlsread('dakin-fig6a.xlsx');

%
%rr = exp5RTs.rt_raw_mean;
%rr = exp5RTs.rt_all_mean; % adjusted for response bias; left/right finger
%rr = exp5RTs.rt_5thr_mean;
rr = exp5RTs.rt_4thr_mean;
rr = rr - exp5RTs.rtblockmean + repmat(mean(mean(rr,1),2),[8,12,1]);

env = [0,15,30,60,90];
fl = exp5.Flank_or;

ns = numel(rr(1,1,:));
rt = rr(4:end,:,:);
for ii=1:ns
  rt(2:4,1:end-1,ii) = ( rt(2:4,1:end-1,ii) + rot90(rr(1:3,1:end-1,ii),2) ) / 2;
  rt(2:4,end,ii) = ( rt(2:4,end,ii) + rot90(rr(1:3,end,ii),2) ) / 2;
endfor

txt = 'abcdef'; lw=1;
rtm = mean( 10.^rt, 3 );
rtse = std( 10.^rt, [], 3 )/sqrt(ns);
figure(3); clf;
for ii = 1:5
  
  subplot(2,3,ii);
  plot( fl, 10.^rt(ii,:,:), '-', 'linewidth',0.5 );
  hold on;
  he = errorbar( fl, rtm(ii,:), rtse(ii,:), 'k-' );
  set(he, 'color', 'k','marker','o','linewidth',lw );
  hold off
  text(-90,1090,txt(ii),'fontsize',22,'fontweight','bold');
  text(-90+30,1090,sprintf('Env: %d', env(ii)),'fontsize',16);
  axis([-95,95,670,1100]); axis square; box off;
  if ii>2 xlabel('Flank orientation (deg)'); endif
  if ii==1 || ii==4 ylabel('Response Time (ms)'); endif
  set(gca,'position',get(gca,'position')+0.02*[-1,0,2,2],...
    'xtick',-90:30:90,'ytick',550:50:1050,'fontsize',16,'layer','top');
  %
  
endfor






%return; 





biases = exp5.Biases(4:end,:,:);
thresh = exp5.Thresholds(4:end,:,:);

env = [0,15,30,60,90];
fl = exp5.Flank_or;

for ii=1:7
  biases(2:4,1:end-1,ii) = ( biases(2:4,1:end-1,ii) - rot90(exp5.Biases(1:3,1:end-1,ii),2) ) / 2;
  thresh(2:4,1:end-1,ii) = ( thresh(2:4,1:end-1,ii) + rot90(exp5.Thresholds(1:3,1:end-1,ii),2) ) / 2;
  biases(2:4,end,ii) = ( biases(2:4,end,ii) - rot90(exp5.Biases(1:3,end,ii),2) ) / 2;
  thresh(2:4,end,ii) = ( thresh(2:4,end,ii) + rot90(exp5.Thresholds(1:3,end,ii),2) ) / 2;
endfor

% means
bm = mean( biases, 3 );
th = mean( thresh, 3 );
bse = std( biases, [], 3 )/sqrt(7);
tse = std( thresh, [], 3 )/sqrt(7);



mar = 'os><^vd'; col = 'kbrmcgy'; c = [ 0.85 0.85 0.85 ];
txt = 'abcdef';

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% FIGURE 1: biases
if 1
  figure(1); clf; % biases
  for ii=1:numel(env)
    subplot(2,3,ii);
    h = area([-90 0 0 90],13*[-1 -1 1 1]);
    set(h,'FaceColor',c,'EdgeColor',c);
    line([-90 ; 90 ], [bm(ii,6) ;bm(ii,6) ],'linestyle','--',...
      'Color',[0.9 0.01 0.01],'linewidth',1.5);
    hold on;
    plot( fl, biases(ii,:,:), '-', 'linewidth',0.5 );
    he = errorbar( fl, bm(ii,:), bse(ii,:), 'ko-' );
    set(he, 'color', 'k','marker','o','linewidth',lw );
    %plot( fl, bm(ii,:), 'ko','markersize',8,'linewidth',1.);
    hold off
    text(-90,11.5,txt(ii),'fontsize',22,'fontweight','bold');
    text(-90,8.5,{['Env ' num2str(env(ii))]},'fontsize',16);
    axis([-95,95,-13,13]); axis square; box off;
    if ii>3 xlabel('Flank orientation (deg)'); endif
    if ii==1 || ii==4 ylabel('Perceived vertical (deg)'); endif
    set(gca,'xtick',-90:30:90,'ytick',-12:4:12,'fontsize',16,'layer','top');
    if ii>3 set(gca,'position',get(gca,'position')+0.01*[-1,2,2,2]);
    else set(gca,'position',get(gca,'position')+0.01*[-1,-4,2,2]); endif
  endfor

  % 6th panel: comparison of single carrier == parallel Gabors
  idxsubjexp1 = [1:9,11];
  exp1.Biases(exp1.Thresholds==0) = nan;
  exp1.Thresholds(exp1.Thresholds==0) = nan;
  biases1 = exp1.Biases(9:end,idxsubjexp1)';
  thresh1 = exp1.Thresholds(9:end,idxsubjexp1)';
  biases1(:,2:end-1) = ( biases1(:,2:end-1) - fliplr( exp1.Biases(1:8,idxsubjexp1)' ) )/2;
  thresh1(:,2:end-1) = ( thresh1(:,2:end-1) + fliplr( exp1.Thresholds(1:8,idxsubjexp1)' ) )/2;
  env1 = exp1.Envelope_or(9:end);

  biases5 = reshape( exp5.Biases(:,6,:), 8, 7 ) ;
  thresh5 = reshape( exp5.Thresholds(:,6,:), 8, 7 ) ;
  b5 = biases5( 4:end, :); b5(2:end-1,:) = ( b5(2:end-1,:) - flipud( biases5( 1:3, :) ) ) /2;
  t5 = thresh5( 4:end,:); t5(2:end-1,:) = ( t5(2:end-1,:) + flipud( thresh5( 1:3, :) ) ) /2;
  env5 = exp5.Envelope_or(4:end);

  dakm = nanmean( bdak(:,2:end), 2 );
  dakse = nanstd( bdak(:,2:end), [], 2 ) ./ sqrt(sum(~isnan(bdak(:,2:end)), 2 ));
  dakenv = flipud(bdak(:,1));
  tdakm = nanmean( tdak(:,2:end), 2 );
  tdakse = nanstd( tdak(:,2:end), [], 2 ) ./ sqrt(sum(~isnan(tdak(:,2:end)), 2 ));

  % means, se
  b1m = nanmean( biases1 ); b1se = nanstd( biases1, [], 1 )./sqrt( sum(~isnan(biases1)) );
  t1m = nanmean( thresh1 ); t1se = nanstd( thresh1, [], 1 )./sqrt( sum(~isnan(biases1)) );

  b5m = mean( b5, 2 ); b5se = std( b5, [], 2 )/sqrt( columns(b5) );
  t5m = mean( t5, 2 ); t5se = std( t5, [], 2 )/sqrt( columns(b5) );

  %figure(1); clf;% biases
  subplot(2,3,6,'replace')
  %plot( dakenv, dakm, 'b^','markersize',8);
  %plot( env5, b5m, 'rs','markersize',8,'linewidth',1.5);
  he1=errorbar( env5, b5m, b5se, 'rs--' ); set(he1,'linewidth',lw);
  hold on;
  he2=errorbar( env1, b1m, b1se, 'ko-' ); set(he2,'linewidth',lw);
  plot( env1, biases1', '-','linewidth',0.5);
  %errorbar( dakenv, dakm, dakse, 'b:' );
  he=errorbar( env1, b1m, b1se, 'ko-' ); set(he,'linewidth',lw);
  he=errorbar( env5, b5m, b5se, 'rs--' ); set(he,'linewidth',lw);
  hold off;
  line([-90 ; 90 ], [0 ;0 ],'linestyle','-','Color','k','linewidth',0.5);
  xlabel('Envelope orientation (deg)');
  set(gca,'position',get(gca,'position')+0.01*[-1,2,2,2],...
    'xtick',0:30:90,'ytick',-12:4:4,'fontsize',16,'layer','top');
  %  hl=legend({'Dakin (1999)';'3 parallel Gabors';'Elongate Gaussian envelope'},...
  %    'box','off','fontsize',8,'location','north');
  hl=legend({'3 parallel Gabors';'Elongate Gaussian envelope'},...
    'box','off','fontsize',8,'location','north');
  set(hl,'position',get(hl,'position')+0.01*[-2,-2,0,0]);
  text(-3,3.5,txt(6),'fontsize',22,'fontweight','bold');
  axis([-5,95,-15,5]); axis square; box off;
endif
%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% FIGURE 2: thresholds
if 1
  mar = 'os><^vd'; col = 'kbrmcgy'; c = [ 0.85 0.85 0.85 ];
  txt = 'abcdef';
  figure(2); clf; % biases
  for ii=1:numel(env)
    subplot(2,3,ii);
    plot( fl, thresh(ii,:,:), '-', 'linewidth',0.5 );
    hold on;
    he = errorbar( fl, th(ii,:), tse(ii,:), 'k-' );
    plot( fl, th(ii,:), 'ko-','markersize',8, 'linewidth',lw);
    hold off
    set(gca,'yscale','log','yticklabel',{'1','2','4','8'});
    text(-90,18,txt(ii),'fontsize',22,'fontweight','bold');
    text(-90,12,{['Env ' num2str(env(ii))]},'fontsize',16);
    axis([-95,95,0.5,20]); axis square; box off;
    if ii>3 xlabel('Flank orientation (deg)'); endif
    if ii==1 || ii==4 ylabel('Orientation threshold (deg)'); endif
    if ii<=3
      set(gca,'position',get(gca,'position')+0.01*[-1,-3,2,2],...
        'xtick',-90:30:90,'ytick',[1,2,4,8],'fontsize',16,'layer','top');
    else
      set(gca,'position',get(gca,'position')+0.01*[-1,1,2,2],...
        'xtick',-90:30:90,'ytick',[1,2,4,8],'fontsize',16,'layer','top');
    endif
  endfor
  
  %
  if 0 % left for people interested to compare the thresholds
    subplot(2,3,6,'replace')
    %plot( dakenv, dakm, 'b^','markersize',8);
    %plot( env5, b5m, 'rs','markersize',8,'linewidth',1.5);
    he1=errorbar( env5, t5m, t5se, 'rs--' ); set(he1,'linewidth',1.);
    hold on;
    he2=errorbar( env1, t1m, t1se, 'ko-' ); set(he2,'linewidth',1.);
    plot( env1, thresh1', '-','linewidth',0.5);
    %errorbar( dakenv, dakm, dakse, 'b:' );
    he=errorbar( env1, t1m, b1se, 'ko-' ); set(he,'linewidth',1.);
    he=errorbar( env5, t5m, b5se, 'rs--' ); set(he,'linewidth',1.);
    hold off;
    line([-90 ; 90 ], [0 ;0 ],'linestyle','-','Color','k','linewidth',0.5);
    xlabel('Envelope orientation (deg)');
    %  hl=legend({'Dakin (1999)';'3 parallel Gabors';'Elongate Gaussian envelope'},...
    %    'box','off','fontsize',8,'location','north');
    hl=legend({'3 parallel Gabors';'Elongate Gaussian envelope'},...
      'box','off','fontsize',8,'location','north');
    set(hl,'position',get(hl,'position')+0.01*[-2,0,0,0]);
    text(-3,15,txt(6),'fontsize',22,'fontweight','bold');
    axis([-5,95,0.5,16]); axis square; box off;
    set(gca,'position',get(gca,'position')+0.01*[-1,1,2,2],...
      'xtick',0:30:90,'ytick',[1,2,4,8],'fontsize',16,'layer','top');
    set(gca,'yscale','log','yticklabel',{'1','2','4','8'});
  endif
endif
%




return;

figure(1);
print('-dpng','-r300',['exp5_biases.png'])

figure(2);
print('-dpng','-r300',['exp5_thresholds.png'])

figure(3);
print('-dpng','-r300',['exp5_RTs.png'])


